import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:sudoku/cubit/game_cubit.dart';
import 'package:sudoku/models/cell_location.dart';
import 'package:sudoku/models/game.dart';
import 'package:sudoku/ui/widgets/cell_widget.dart';

class BoardLayout extends StatelessWidget {
  const BoardLayout({super.key});

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<GameCubit, GameState>(
      builder: (BuildContext context, GameState gameState) {
        final Game game = gameState.game;

        final Color borderColor = Theme.of(context).colorScheme.onBackground;

        return Container(
          margin: const EdgeInsets.all(2),
          padding: const EdgeInsets.all(2),
          decoration: BoxDecoration(
            color: borderColor,
            borderRadius: BorderRadius.circular(2),
            border: Border.all(
              color: borderColor,
              width: 2,
            ),
          ),
          child: Column(
            children: [
              Table(
                defaultColumnWidth: const IntrinsicColumnWidth(),
                children: [
                  for (int row = 0; row < game.boardSize; row++)
                    TableRow(
                      children: [
                        for (int col = 0; col < game.boardSize; col++)
                          Column(
                            children: [
                              CellWidget(cell: game.board.get(CellLocation.go(row, col)))
                            ],
                          ),
                      ],
                    ),
                ],
              ),
            ],
          ),
        );
      },
    );
  }
}
